@@ -1,6 +1,7 @@
 # TOOL tophat.R: "TopHat for paired end reads" (Aligns paired end Illumina RNA-Seq reads to a genome in order to identify exon-exon splice junctions. TopHat first identifies potential exons by mapping the reads to the genome. Using this initial mapping, it builds a database of possible splice junctions, and then maps the reads against these junctions to confirm them. The alignment results are given in a BAM file which is automatically indexed and hence ready to be viewed in Chipster genome browser.)
 # INPUT reads1.fq: "Reads to align" TYPE GENERIC
 # INPUT reads2.fq: "Reads to align" TYPE GENERIC
+# INPUT OPTIONAL genes.gtf: "Optional GTF file" TYPE GENERIC
 # OUTPUT tophat.bam
 # OUTPUT tophat.bam.bai
 # OUTPUT junctions.bed
@@ -13,6 +14,11 @@
 # PARAMETER OPTIONAL min.intron.length: "Minimum intron length" TYPE INTEGER FROM 10 TO 1000 DEFAULT 70 (TopHat will ignore donor-acceptor pairs closer than this many bases apart.)
 # PARAMETER OPTIONAL max.intron.length: "Maximum intron length" TYPE INTEGER FROM 1000 TO 1000000 DEFAULT 500000 (TopHat will ignore donor-acceptor pairs farther than this many bases apart, except when such a pair is supported by a split segment alignment of a long read.)
 # PARAMETER OPTIONAL min.isoform.fraction: "Minimum isoform fraction" TYPE DECIMAL FROM 0 TO 1 DEFAULT 0.15 (TopHat filters out junctions supported by too few alignments. Suppose a junction spanning two exons is supported by S reads. Let the average depth of coverage of exon A be D, and assume that it is higher than B. If S divided by D is less than the minimum isoform fraction, the junction is not reported. A value of zero disables the filter.)
+# PARAMETER OPTIONAL max.multihits: "How many hits is a read allowed to have" TYPE INTEGER FROM 1 TO 1000000 DEFAULT 20 (Instructs TopHat to allow up to this many alignments to the reference for a given read, and suppresses all alignments for reads with more than this many alignments.)
+# PARAMETER OPTIONAL no.novel.juncs: "When GTF file is supplied, ignore novel junctions" TYPE [yes, no] DEFAULT yes (If you supply an optional GTF file, TopHat will use the exon records in this file to build a set of known splice site junctions for each gene, and it will attempt to align reads to these junctions even if they would not normally be covered by the initial mapping. This parameter controls if TopHat should look for reads accross the known junctions only.)
+
+# EK 17.4.2012 added -G and -g options
+# MG 24.4.2012 added ability to use gtf files from Chipster server
 
 options(scipen = 10)
 # max.intron.length <- formatC(max.intron.length, "f", digits = 0)
@@ -24,19 +30,53 @@ path.samtools <- c(file.path(chipster.tools.path, "samtools"))
 set.path <-paste(sep="", "PATH=", path.bowtie, ":", path.samtools, ":$PATH")
 path.bowtie.index <- c(file.path(path.bowtie, "indexes", genome))
 
-
 # command start
 command.start <- paste("bash -c '", set.path, tophat.binary)
 
 # parameters
-command.parameters <- paste("-r", mate.inner.distance, "-a", min.anchor.length, "-m", splice.mismatches, "-i", min.intron.length, "-I", max.intron.length, "-F", min.isoform.fraction, "--library-type fr-unstranded")
+command.parameters <- paste("-r", mate.inner.distance, "-a", min.anchor.length, "-m", splice.mismatches, "-i", min.intron.length, "-I", max.intron.length, "-F", min.isoform.fraction, "-g", max.multihits, "--library-type fr-unstranded")
 
+# optional GTF command, if a GTF file has been provided by user
+command.gtf <- ""
+input_files <- dir()
+is_gtf <- (length(grep("genes.gtf", input_files))>0)
+if (is_gtf) {
+	if (no.novel.juncs == "yes") {
+		command.gtf <- paste("-G", "genes.gtf", "--no-novel-juncs")
+	} else {
+		command.gtf <- paste("-G", "genes.gtf")
+	}
+}
+
+# optional GTF command, if a GTF file has NOT been provided by user
+# BUT is avaliable from Chipster server
+if (genome == "hg19" ||	genome == "mm9" || genome == "rn4") genome_available <- TRUE
+if (!is_gtf && genome_available) {
+
+	# annotation file setup
+	if (genome == "hg19") {
+		annotation.file <- "Homo_sapiens.GRCh37.62.chr.gtf"
+	}
+	if (genome == "mm9") {
+		annotation.file <- "Mus_musculus.NCBIM37.62.chr.gtf"
+	}
+	if (genome == "rn4") {
+		annotation.file <- "Rattus_norvegicus.RGSC3.4.62.chr.gtf"
+	}
+	annotation.file <- c(file.path(chipster.tools.path, "genomes", annotation.file))
+	
+	if (no.novel.juncs == "yes") {
+		command.gtf <- paste("-G", annotation.file, "--no-novel-juncs")
+	} else {
+		command.gtf <- paste("-G", annotation.file)
+	}
+}
 
 # command ending
 command.end <- paste(path.bowtie.index, "reads1.fq reads2.fq'")
 
 # run tophat
-command <- paste(command.start, command.parameters, command.end)
+command <- paste(command.start, command.parameters, command.gtf, command.end)
 system(command)
 
 # samtools binary
